# atd-data-utils-kits (kitsuitl)
Python utilities for interacting with KITS, an advanced transportation management application

## Installation

```bash
$ pip install atd_kitsutil
```
## License
As a work of the City of Austin, this project is in the public domain within the United States.

Additionally, we waive copyright and related rights of the work worldwide through the [CC0 1.0 Universal public domain dedication](https://creativecommons.org/publicdomain/zero/1.0/).
